@@ -392,6 +392,65 @@ class usermgmt {
         }
     }
 
+    /**
+     * Get PostgreSQL password for user
+     */
+    public function getUserPostgreSQLPassword($username) {
+        try {
+            require_once('/docker/whp/web/libs/mysqlmgmt.php');
+            $MySQLMgmt = new mysqlmgmt();
+            $pdo = $MySQLMgmt->getMySQLConnection();
+            
+            if (!$pdo) {
+                return false;
+            }
+            
+            $stmt = $pdo->prepare("SELECT postgresql_password FROM whp.user_passwords WHERE username = ?");
+            $stmt->execute([$username]);
+            $result = $stmt->fetch();
+            
+            if ($result && $result['postgresql_password']) {
+                // Decrypt the PostgreSQL password (base64 decode for now)
+                return base64_decode($result['postgresql_password']);
+            }
+            
+            return false;
+        } catch (Exception $e) {
+            error_log("Failed to get PostgreSQL password for user $username: " . $e->getMessage());
+            return false;
+        }
+    }
+
+    /**
+     * Set PostgreSQL password for user
+     */
+    public function setUserPostgreSQLPassword($username, $password) {
+        try {
+            require_once('/docker/whp/web/libs/mysqlmgmt.php');
+            $MySQLMgmt = new mysqlmgmt();
+            $pdo = $MySQLMgmt->getMySQLConnection();
+            
+            if (!$pdo) {
+                return false;
+            }
+            
+            // Encrypt the PostgreSQL password for storage (simple base64 encoding for now)
+            $postgresql_password_encrypted = base64_encode($password);
+            
+            // Insert or update the password record
+            $stmt = $pdo->prepare("INSERT INTO whp.user_passwords (username, password_hash, mysql_password, postgresql_password) 
+                                  VALUES (?, '', '', ?) 
+                                  ON DUPLICATE KEY UPDATE 
+                                  postgresql_password = VALUES(postgresql_password)");
+            $stmt->execute([$username, $postgresql_password_encrypted]);
+            
+            return true;
+        } catch (Exception $e) {
+            error_log("Failed to set PostgreSQL password for user $username: " . $e->getMessage());
+            return false;
+        }
+    }
+
     public function create_new_user( $username, $password, $skip_default_resources = false ) {
         // Check if user exists
         $id = shell_exec("/usr/bin/id -u $username");
