@@ -20,7 +20,7 @@ $is_root = (defined('AUTH_USER') && AUTH_USER === 'root');
 <?php endif; ?>
 
 <div class="alert alert-warning" role="alert">
-    <h6 class="alert-heading mb-2"><i class="fas fa-exclamation-triangle"></i> Important Notice</h6>
+    <h6 class="alert-heading mb-2"><i class="fa fa-exclamation-triangle"></i> Important Notice</h6>
     <p class="mb-1"><strong>Container modifications will not persist.</strong> Containers may be refreshed at any time, which will reset any changes you make to the container filesystem.</p>
     <p class="mb-0">If you need a customized container with persistent modifications, please contact support to discuss custom container solutions.</p>
 </div>
